@@ -27,7 +27,7 @@ use Excel::Writer::XLSX::Package::Styles;
 use Excel::Writer::XLSX::Package::Theme;
 
 our @ISA     = qw(Exporter);
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 
 ###############################################################################
@@ -297,9 +297,10 @@ sub _write_shared_strings_file {
 #
 sub _write_app_file {
 
-    my $self = shift;
-    my $dir  = $self->{_package_dir};
-    my $app  = Excel::Writer::XLSX::Package::App->new();
+    my $self       = shift;
+    my $dir        = $self->{_package_dir};
+    my $properties = $self->{_workbook}->{_doc_properties};
+    my $app        = Excel::Writer::XLSX::Package::App->new();
 
     mkdir $dir . '/docProps';
 
@@ -331,6 +332,7 @@ sub _write_app_file {
         $app->_add_part_name( $named_range );
     }
 
+    $app->_set_properties( $properties );
 
     $app->_set_xml_writer( $dir . '/docProps/app.xml' );
     $app->_assemble_xml_file();
@@ -345,16 +347,14 @@ sub _write_app_file {
 #
 sub _write_core_file {
 
-    my $self = shift;
-    my $dir  = $self->{_package_dir};
-    my $core = Excel::Writer::XLSX::Package::Core->new();
+    my $self       = shift;
+    my $dir        = $self->{_package_dir};
+    my $properties = $self->{_workbook}->{_doc_properties};
+    my $core       = Excel::Writer::XLSX::Package::Core->new();
 
     mkdir $dir . '/docProps';
 
-    my $date = _localtime_to_iso8601_date();
-
-    $core->_set_creation_date( $date );
-    $core->_set_modification_date( $date );
+    $core->_set_properties( $properties );
     $core->_set_xml_writer( $dir . '/docProps/core.xml' );
     $core->_assemble_xml_file();
 }
@@ -659,27 +659,6 @@ sub _write_drawing_rels_files {
 }
 
 
-###############################################################################
-#
-# _localtime_to_iso8601_date()
-#
-# Convert a localtime() date to a ISO 8601 style "2010-01-01T00:00:00Z" date.
-#
-sub _localtime_to_iso8601_date {
-
-    my $self = shift;
-    my $time = shift // time();
-
-    my ( $seconds, $minutes, $hours, $day, $month, $year ) = localtime( $time );
-
-    $month++;
-    $year += 1900;
-
-    my $date = sprintf "%4d-%02d-%02dT%02d:%02d:%02dZ", $year, $month, $day,
-      $hours, $minutes, $seconds;
-}
-
-
 1;
 
 
