@@ -2,7 +2,7 @@ package Excel::Writer::XLSX::Workbook;
 
 ###############################################################################
 #
-# Workbook - A writer class for Excel Workbooks.
+# Workbook - A class for writing Excel Workbooks.
 #
 #
 # Used in conjunction with Excel::Writer::XLSX
@@ -30,7 +30,7 @@ use Excel::Writer::XLSX::Package::XMLwriter;
 use Excel::Writer::XLSX::Utility qw(xl_cell_to_rowcol xl_rowcol_to_cell);
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 
 ###############################################################################
@@ -74,6 +74,8 @@ sub new {
     $self->{_defined_names}    = [];
     $self->{_named_ranges}     = [];
     $self->{_custom_colors}    = [];
+    $self->{_doc_properties}   = {};
+    $self->{_localtime}        = [ localtime() ];
 
     # Structures for the shared strings data.
     $self->{_str_total}  = 0;
@@ -82,6 +84,8 @@ sub new {
     $self->{_str_array}  = [];
 
 
+
+
     bless $self, $class;
 
     # Add the default cell format.
@@ -622,6 +626,59 @@ sub set_tempdir {
 }
 
 
+
+
+###############################################################################
+#
+# set_properties()
+#
+# Set the document properties such as Title, Author etc. These are written to
+# property sets in the OLE container.
+#
+sub set_properties {
+
+    my $self  = shift;
+    my %param = @_;
+
+    # Ignore if no args were passed.
+    return -1 unless @_;
+
+    # List of valid input parameters.
+    my %valid = (
+        title       => 1,
+        subject     => 1,
+        author      => 1,
+        keywords    => 1,
+        comments    => 1,
+        last_author => 1,
+        created     => 1,
+        category    => 1,
+        manager     => 1,
+        company     => 1,
+        status      => 1,
+    );
+
+    # Check for valid input parameters.
+    for my $parameter ( keys %param ) {
+        if ( not exists $valid{$parameter} ) {
+            carp "Unknown parameter '$parameter' in set_properties()";
+            return -1;
+        }
+    }
+
+    # Set the creation time unless specified by the user.
+    if ( !exists $param{created} ) {
+        $param{created} = $self->{_localtime};
+    }
+
+
+    $self->{_doc_properties} = \%param;
+}
+
+
+
+
+
 ###############################################################################
 #
 # _store_workbook()
@@ -1503,7 +1560,7 @@ __END__
 
 =head1 NAME
 
-Workbook - A writer class for Excel Workbooks.
+Workbook - A class for writing Excel Workbooks.
 
 =head1 SYNOPSIS
 
